## WebGym

The WebGym package provides learning environments for agents to perceive the world-wide-web like how we (humans) perceive – using the pixels rendered on to the display screen. The agent interacts with the environment using keyboard and mouse events as actions. This allows the agent to experience the world-wide-web like how we do thereby require no new additional modifications for the agents to train. This allows us to train RL agents that can directly work with the web-based pages and applications to complete real-world tasks. It is an extension of Wolrd-Of-Bits (WOB) & MiniWoB++.

WebGym is part of [TensorFlow Reinforcement Learning Cookbook](https://github.com/PacktPublishing/Tensorflow-2-Reinforcement-Learning-Cookbook). More details about this package, see Deep RL Web Assistants discussed in **Chapter 6 - RL in real-world: Building intelligent agents to complete your To-dos**
